@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.4
+# Version   : 0.2.5
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -465,14 +465,14 @@ class AFM:
         _def_sens = _params.Tip.Sensitivity['Value']
         _spr_const = _params.Tip.Prop0['Value']
 
-
         self.def_sens = float(_def_sens)
         self.spr_const = float(_spr_const)
+        self.samps_line = int(_approach[0].shape[0])
 
-        self.approach_raw = _approach
-        self.retract_raw = _withdraw
-        self.z_approach = _z_approach
-        self.z_withdraw = _z_withdraw
+        self.approach_raw = np.array(_approach, dtype=object)
+        self.retract_raw = np.array(_withdraw, dtype=object)
+        self.z_approach = np.array(_z_approach, dtype=object)
+        self.z_withdraw = np.array(_z_withdraw, dtype=object)
 
     def plot_raw(
         self,
@@ -520,10 +520,10 @@ class AFM:
         'max_approach_noise' and 'max_retract_noise' respectivley. The defaults for
         each are 1000 nN (i.e. all curves retained).
         '''
-        self.approach = np.zeros([self.samps_line, len(self.filelist)])
-        self.retract = np.zeros([self.samps_line, len(self.filelist)])
-        self.z_approach = np.zeros([self.samps_line, len(self.filelist)])
-        self.z_withdraw = np.zeros([self.samps_line, len(self.filelist)])
+        self.approach = np.zeros([self.samps_line, len(self.approach_raw)])
+        self.retract = np.zeros([self.samps_line, len(self.approach_raw)])
+        self.z_approach = np.zeros([self.samps_line, len(self.approach_raw)])
+        self.z_withdraw = np.zeros([self.samps_line, len(self.approach_raw)])
 
         i = 0
         
